[![PyPI](https://img.shields.io/pypi/v/pymdgen.svg?maxAge=3600)](https://pypi.python.org/pypi/pymdgen)
[![PyPI](https://img.shields.io/pypi/pyversions/pymdgen.svg?maxAge=600)](https://pypi.python.org/pypi/pymdgen)
[![Tests](https://github.com/20c/pymdgen/workflows/tests/badge.svg)](https://github.com/20c/pymdgen)
[![Codecov](https://img.shields.io/codecov/c/github/20c/pymdgen/master.svg?maxAge=3600)](https://codecov.io/github/20c/pymdgen)

A python code markdown documentation generator

# Documentation

- [latest](https://pymdgen.readthedocs.io/en/latest/)


